@@ -1,5 +1,5 @@
 package IRC::Toolkit::Masks;
-$IRC::Toolkit::Masks::VERSION = '0.090002';
+$IRC::Toolkit::Masks::VERSION = '0.090003';
 use Carp;
 use strictures 2;
 
@@ -17,15 +17,13 @@ sub matches_mask {
   ## Imported from IRC::Utils:
   my ($mask, $nuh, $casemap) = @_;
   confess "Expected a mask, a string to match, and optional casemap"
-    unless defined $mask and length $mask
-    and    defined $nuh;
+    unless length $mask and defined $nuh;
 
   my $quoted = quotemeta uc_irc $mask, $casemap;
   $quoted =~ s/\\\*/[\x01-\xFF]{0,}/g;
   $quoted =~ s/\\\?/[\x01-\xFF]{1,1}/g;
 
-  $nuh = uc_irc $nuh, $casemap;
-  $nuh =~ /^$quoted$/ ? 1 : ()
+  !! ( uc_irc($nuh, $casemap) =~ /^$quoted$/ )
 }
 
 sub normalize_mask {
@@ -37,26 +35,24 @@ sub normalize_mask {
   ## **+ --> *
   $orig =~ s/\*{2,}/*/g;
 
-  my @mask;
-  my $piece;
-
-  ## Push nick, if we have one, or * if we don't.
+  my ($piece, @mask);
+  ## nick, if we have one, or * if we don't.
   if ( index($orig, '!') == -1 && index($orig, '@') > -1) {
     $piece = $orig;
-    push(@mask, '*');
+    push @mask, '*';
   } else {
     ($mask[0], $piece) = split /!/, $orig, 2;
   }
 
-  ## Split user/host portions and do some clean up.
-  $piece        =~ s/!//g if defined $piece;
-  @mask[1 .. 2] = split /@/, $piece, 2 if defined $piece;
-  $mask[2]      =~ s/@//g if defined $mask[2];
-  for ( 1 .. 2 ) {
-    $mask[$_] = '*' unless defined $mask[$_]
+  ## user/host portions
+  if (defined $piece) {
+    $piece      =~ s/!//g;
+    @mask[1, 2] = split /@/, $piece, 2;
   }
 
-  $mask[0] . '!' . $mask[1] . '@' . $mask[2]
+  $mask[0] 
+  . '!' . (defined $mask[1] ? $mask[1] : '*' )
+  . '@' . (defined $mask[2] ? ($mask[2] =~ s/@//g, $mask[2]) : '*' )
 }
 
 sub parse_user {
